@@ -1,21 +1,22 @@
 ## Simple interface to googlemaps
-## see the footer for ideas on how to access GMap2 API
 
+## Can show a map with some programmatic markup possible
+## The API key is set in the RApache configuration.
+## the key comes from google : http://code.google.com/apis/maps
+
+## XXX The handler code is not currently working. XXX
+
+## see the footer for ideas on how to access GMap2 API
 ## Use obj[,] <- data.frame(lat,long,title) to set markers
 ## * markers: [geoCodeAddr], [geoCodeAddr, title], [lat, long], [lat,long,title]
 
 ## center and markers set *prior* to rendering. No methods after (possible, not done)
 
-## the key comes from google : http://code.google.com/apis/maps
-## the key is per domain. The default is 127.0.0:8079
-
 
 
 ggooglemaps <- function(x, title = "",  type = c("map","panorama"),
-                        key = "ABQIAAAAYpRTbDoR3NFWvhN4JrY1ahS5eHnalTx_x--TpGz1e2ncErJceBS7FrNBqzV5DPxkpbheIzZ9nTJPsQ", ## for 127.0.0.1:8079 Rpad local default
                         container, ...) {
   widget <- EXTComponent$new(toplevel=container$toplevel,
-                             ..key = key,
                              ..title = title,
                              ..gmapType = match.arg(type))
   class(widget) <- c("gGoogleMap",class(widget))
@@ -26,143 +27,9 @@ ggooglemaps <- function(x, title = "",  type = c("map","panorama"),
   
 
   widget$scripts <- function(.) {
-    out <- String('\n') +
-      'var head = document.getElementsByTagName("head")[0];' +
-        'var s = document.createElement("script");' +
-          's.setAttribute("src",  "http://maps.google.com/maps?file=api&v=2.x&key=' +
-            .$..key + '");' +
-              's.setAttribute("type","text/javascript");' +
-                'head.appendChild(s);' + '\n' 
-    ## The above fails, as it reloads the page (Why?)
-    ## as such we just restart ...
-    out <- String("\n") 
-    out <- out +
-      paste('/**',
-            '* http://extjs.com/blog/2008/07/01/integrating-google-maps-api-with-extjs/',
-            '* author Shea Frederick -- says code is "Lars - Free as a bird. Use it anywhere or any way you like"',
-            '*/',
-              '',
-            'Ext.namespace("Ext.ux");',
-            '/**',
-            '*',
-            '* @class GMaPanel',
-            '* @extends Ext.Panel',
-            '*/',
-            'Ext.ux.GMapPanel = Ext.extend(Ext.Panel, {',
-            'initComponent : function(){',
-            'var defConfig = {',
-            'plain: true,',
-            'zoomLevel: 3,',
-            'yaw: 180,',
-            'pitch: 0,',
-            'zoom: 0,',
-            'gmapType: "map",',
-            'border: false',
-            '}',
-            'Ext.applyIf(this,defConfig);',
-                                        'Ext.ux.GMapPanel.superclass.initComponent.call(this);        ',
-            '},',
-            'afterRender : function(){',
-            'var wh = this.ownerCt.getSize();',
-            'Ext.applyIf(this, wh);',
-            'Ext.ux.GMapPanel.superclass.afterRender.call(this);	',
-            'if (this.gmapType === "map"){',
-            'this.gmap = new GMap2(this.body.dom);',
-            '}',
-            'if (this.gmapType === "panorama"){',
-            'this.gmap = new GStreetviewPanorama(this.body.dom);',
-            '}',
-            'if (typeof this.addControl === "object" && this.gmapType === "map") {',
-            'this.gmap.addControl(this.addControl);',
-            '}',
-            'if (typeof this.setCenter === "object") {',
-            'if (typeof this.setCenter.geoCodeAddr === "string"){',
-            'this.geoCodeLookup(this.setCenter.geoCodeAddr);',
-            '}else{',
-            'if (this.gmapType === "map"){',
-            'var point = new GLatLng(this.setCenter.lat,this.setCenter["long"]);',
-            'this.gmap.setCenter(point, this.zoomLevel);	',
-            '}',
-            'if (typeof this.setCenter.marker === "object" && typeof point === "object"){',
-            'this.addMarker(point,this.setCenter.marker,this.setCenter.marker.clear);',
-            '}',
-            '}',
-            'if (this.gmapType === "panorama"){',
-            'this.gmap.setLocationAndPOV(new GLatLng(this.setCenter.lat,this.setCenter["long"]), {yaw: this.yaw, pitch: this.pitch, zoom: this.zoom});',
-            '}',
-            '}',
-            'var dt = new Ext.util.DelayedTask();',
-            'dt.delay(300, function(){',
-            'this.addMarkers(this.markers);',
-            '}, this);',
-            '},',
-            'onResize : function(w, h){',
-            'if (typeof this.gmap == "object") {',
-            'this.gmap.checkResize();',
-            '}',
-            'Ext.ux.GMapPanel.superclass.onResize.call(this, w, h);',
-            '},',
-            'setSize : function(width, height, animate){',
-            'if (typeof this.gmap == "object") {',
-            'this.gmap.checkResize();',
-            '}',
-            'Ext.ux.GMapPanel.superclass.setSize.call(this, width, height, animate);',
-            '},',
-            'getMap: function(){',
-            'return this.gmap;',
-            '},',
-            'addMarkers: function(markers) {',
-            'if (Ext.isArray(markers)){',
-            'for (var i = 0; i < markers.length; i++) {',
-            'var mkr_point = new GLatLng(markers[i].lat,markers[i]["long"]);',
-            'this.addMarker(mkr_point,markers[i].marker,false,markers[i].setCenter);',
-            '}',
-            '}',
-            '',
-            '},',
-            'addMarker: function(point, marker, clear, center){',
-            'Ext.applyIf(marker,G_DEFAULT_ICON);',
-            'if (clear === true){',
-            'this.gmap.clearOverlays();',
-            '}',
-            'if (center === true) {',
-            'this.gmap.setCenter(point, this.zoomLevel);',
-            '}',
-            'var mark = new GMarker(point,marker);',
-            'this.gmap.addOverlay(mark);',
-            '},',
-            'geoCodeLookup : function(addr) {',
-            'this.geocoder = new GClientGeocoder();',
-            'this.geocoder.getLocations(addr, this.addAddressToMap.createDelegate(this));',
-            '},',
-            'addAddressToMap : function(response) {',
-            'if (!response || response.Status.code != 200) {',
-            'Ext.MessageBox.alert("Error", "Code "+response.Status.code+" Error Returned");',
-            '} else {',
-            'place = response.Placemark[0];',
-            'addressinfo = place.AddressDetails;',
-            'accuracy = addressinfo.Accuracy;',
-            'if (accuracy === 0) {',
-            'Ext.MessageBox.alert("Unable to Locate Address", "Unable to Locate the Address you provided");',
-            '}else{',
-            'if (accuracy < 7) {',
-            'Ext.MessageBox.alert("Address Accuracy", "The address provided has a low accuracy.<br><br>Level "+accuracy+" Accuracy (8 = Exact Match, 1 = Vague Match)");',
-            '}else{',
-            'point = new GLatLng(place.Point.coordinates[1], place.Point.coordinates[0]);',
-            'if (typeof this.setCenter.marker === "object" && typeof point === "object"){',
-            'this.addMarker(point,this.setCenter.marker,this.setCenter.marker.clear,true);',
-            '}',
-            '}',
-            '}',
-            '}',
-            '',
-            '}',
-            '',
-            '});',
-            '',
-            'Ext.reg("gmappanel",Ext.ux.GMapPanel);' ,
-            sep = "\n")
-            
+    f <- system.file("javascript","GMapPanel.js", package="gWidgetsWWW")
+    out <- paste(readLines(f), collapse="\n")
+    
     return(out)
   }
 
@@ -223,8 +90,8 @@ widget$makeMarkers <- function(.) {
                 zoomLevel = .$..zoomLevel,
                 gmapType = .$..gmapType,
                 width = .$..width,
-                height = .$..height,
-                addControl = String("new GSmallMapControl()")
+                height = .$..height #,
+#                addControl = String("new GSmallMapControl()")
                 )
     val <- svalue(.)
     if(length(val) == 1) {
@@ -315,11 +182,11 @@ widget$makeMarkers <- function(.) {
     pat.sw = String(.$ID) + '.SouthWest'
     pat.ne = String(.$ID) + '.NorthEast'
 
-    sw <- get(pat.sw,envir=.GlobalEnv)
-    sw <- eval(parse(text = String("c") + sw), envir=.GlobalEnv)
+    sw <- get(pat.sw,envir=.)
+    sw <- eval(parse(text = String("c") + sw), envir=.)
 
-    ne <- get(pat.ne,envir=.GlobalEnv)
-    ne <- eval(parse(text = String("c") + ne), envir=.GlobalEnv)
+    ne <- get(pat.ne,envir=.)
+    ne <- eval(parse(text = String("c") + ne), envir=.)
     ## coerce
 
     ## return
@@ -518,13 +385,13 @@ widget$makeMarkers <- function(.) {
           ',function(overlay, point) {' +
             ## transport bounds
             'var bounds = ' + .$gmapID() + '.getBounds();' +
-              '_transportToR("' + .$ID + '.SouthWest",' +
-                'bounds.getSouthWest().toString());' +
-                  '_transportToR("' + .$ID + '.NorthEast",' +
-                    'bounds.getNorthEast().toString());' +
-                      'runHandlerJS(' + handler$handlerID +
-                        ',"latlng","evalme c" + point.toString());' +
-                          '});'
+              'var SW = bounds.getSouthWest().toString();' +
+                'var NE = bounds.getNorthEast().toString();' +
+                  '_transportToR("' + .$ID + '.SouthWest",SW);' +
+                    '_transportToR("' + .$ID + '.NorthEast",NE);' +
+                      'runHandlerJS(' + handler$handlerID + ',"","")' +
+                        ##                        ',"latlng","evalme c" + point.toString());' +
+                        '});'
     return(out)
   }
 
